# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-09-02 02:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('link', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ViewParam',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=64)),
                ('value', models.CharField(max_length=256)),
            ],
        ),
        migrations.AddField(
            model_name='link',
            name='view_params',
            field=models.ManyToManyField(blank=True, null=True, to='link.ViewParam'),
        ),
    ]
