# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-24 10:49
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('link', '0002_auto_20160902_0249'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='viewparam',
            options={'ordering': ['key']},
        ),
    ]
