# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-09-01 09:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Link',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(help_text=b'A short descriptive title.', max_length=256)),
                ('slug', models.SlugField(max_length=256)),
                ('view_name', models.CharField(blank=True, help_text=b'View name to which this link will redirect.', max_length=256, null=True)),
                ('target_object_id', models.PositiveIntegerField(blank=True, null=True)),
                ('url', models.CharField(blank=True, help_text=b'URL to which this link will redirect.', max_length=256, null=True)),
                ('target_content_type', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='link_target_content_type', to='contenttypes.ContentType')),
            ],
            options={
                'ordering': ['title'],
            },
        ),
    ]
